@@ -19,16 +19,20 @@ from typing import Any, Dict, List, Type
 from botocore.client import ClientMeta
 
 from .literals import (
-    ExportableAutoScalingGroupField,
-    ExportableInstanceField,
-    MetricStatistic,
-    Status,
+    ExportableAutoScalingGroupFieldType,
+    ExportableInstanceFieldType,
+    ExportableLambdaFunctionFieldType,
+    ExportableVolumeFieldType,
+    MetricStatisticType,
+    StatusType,
 )
 from .type_defs import (
     DescribeRecommendationExportJobsResponseTypeDef,
     EBSFilterTypeDef,
     ExportAutoScalingGroupRecommendationsResponseTypeDef,
+    ExportEBSVolumeRecommendationsResponseTypeDef,
     ExportEC2InstanceRecommendationsResponseTypeDef,
+    ExportLambdaFunctionRecommendationsResponseTypeDef,
     FilterTypeDef,
     GetAutoScalingGroupRecommendationsResponseTypeDef,
     GetEBSVolumeRecommendationsResponseTypeDef,
@@ -75,7 +79,7 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -84,8 +88,8 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def describe_recommendation_export_jobs(
@@ -96,8 +100,8 @@ class ComputeOptimizerClient:
         maxResults: int = None,
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
-        [Show boto3-stubs documentation](./client.md#describe-recommendation-export-jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3-stubs documentation](./client.md#describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
@@ -105,13 +109,27 @@ class ComputeOptimizerClient:
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[FilterTypeDef] = None,
-        fieldsToExport: List[ExportableAutoScalingGroupField] = None,
+        fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None,
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
-        [Show boto3-stubs documentation](./client.md#export-auto-scaling-group-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3-stubs documentation](./client.md#export_auto_scaling_group_recommendations)
+        """
+
+    def export_ebs_volume_recommendations(
+        self,
+        s3DestinationConfig: S3DestinationConfigTypeDef,
+        accountIds: List[str] = None,
+        filters: List[EBSFilterTypeDef] = None,
+        fieldsToExport: List[ExportableVolumeFieldType] = None,
+        fileFormat: Literal["Csv"] = None,
+        includeMemberAccounts: bool = None,
+    ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3-stubs documentation](./client.md#export_ebs_volume_recommendations)
         """
 
     def export_ec2_instance_recommendations(
@@ -119,13 +137,27 @@ class ComputeOptimizerClient:
         s3DestinationConfig: S3DestinationConfigTypeDef,
         accountIds: List[str] = None,
         filters: List[FilterTypeDef] = None,
-        fieldsToExport: List[ExportableInstanceField] = None,
+        fieldsToExport: List[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None,
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
-        [Show boto3-stubs documentation](./client.md#export-ec2-instance-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3-stubs documentation](./client.md#export_ec2_instance_recommendations)
+        """
+
+    def export_lambda_function_recommendations(
+        self,
+        s3DestinationConfig: S3DestinationConfigTypeDef,
+        accountIds: List[str] = None,
+        filters: List[LambdaFunctionRecommendationFilterTypeDef] = None,
+        fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
+        fileFormat: Literal["Csv"] = None,
+        includeMemberAccounts: bool = None,
+    ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3-stubs documentation](./client.md#export_lambda_function_recommendations)
         """
 
     def generate_presigned_url(
@@ -136,8 +168,8 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
@@ -149,8 +181,8 @@ class ComputeOptimizerClient:
         filters: List[FilterTypeDef] = None,
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
-        [Show boto3-stubs documentation](./client.md#get-auto-scaling-group-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_auto_scaling_group_recommendations)
         """
 
     def get_ebs_volume_recommendations(
@@ -162,8 +194,8 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
-        [Show boto3-stubs documentation](./client.md#get-ebs-volume-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_ebs_volume_recommendations)
         """
 
     def get_ec2_instance_recommendations(
@@ -175,27 +207,27 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
-        [Show boto3-stubs documentation](./client.md#get-ec2-instance-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
         self,
         instanceArn: str,
-        stat: MetricStatistic,
+        stat: MetricStatisticType,
         period: int,
         startTime: datetime,
         endTime: datetime,
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
-        [Show boto3-stubs documentation](./client.md#get-ec2-recommendation-projected-metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3-stubs documentation](./client.md#get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
-        [Show boto3-stubs documentation](./client.md#get-enrollment-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3-stubs documentation](./client.md#get_enrollment_status)
         """
 
     def get_lambda_function_recommendations(
@@ -207,22 +239,22 @@ class ComputeOptimizerClient:
         maxResults: int = None,
     ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
-        [Show boto3-stubs documentation](./client.md#get-lambda-function-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
         self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
-        [Show boto3-stubs documentation](./client.md#get-recommendation-summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3-stubs documentation](./client.md#get_recommendation_summaries)
         """
 
     def update_enrollment_status(
-        self, status: Status, includeMemberAccounts: bool = None
+        self, status: StatusType, includeMemberAccounts: bool = None
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
-        [Show boto3-stubs documentation](./client.md#update-enrollment-status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.77/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3-stubs documentation](./client.md#update_enrollment_status)
         """
