@@ -16,24 +16,24 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    EBSFinding,
-    EBSMetricName,
-    FilterName,
-    Finding,
-    FindingReasonCode,
-    JobFilterName,
-    JobStatus,
-    LambdaFunctionMemoryMetricStatistic,
-    LambdaFunctionMetricName,
-    LambdaFunctionMetricStatistic,
-    LambdaFunctionRecommendationFilterName,
-    LambdaFunctionRecommendationFinding,
-    LambdaFunctionRecommendationFindingReasonCode,
-    MetricName,
-    MetricStatistic,
-    RecommendationSourceType,
-    ResourceType,
-    Status,
+    EBSFindingType,
+    EBSMetricNameType,
+    FilterNameType,
+    FindingReasonCodeType,
+    FindingType,
+    JobFilterNameType,
+    JobStatusType,
+    LambdaFunctionMemoryMetricStatisticType,
+    LambdaFunctionMetricNameType,
+    LambdaFunctionMetricStatisticType,
+    LambdaFunctionRecommendationFilterNameType,
+    LambdaFunctionRecommendationFindingReasonCodeType,
+    LambdaFunctionRecommendationFindingType,
+    MetricNameType,
+    MetricStatisticType,
+    RecommendationSourceTypeType,
+    ResourceTypeType,
+    StatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -55,7 +55,9 @@ __all__ = (
     "EBSUtilizationMetricTypeDef",
     "ExportAutoScalingGroupRecommendationsResponseTypeDef",
     "ExportDestinationTypeDef",
+    "ExportEBSVolumeRecommendationsResponseTypeDef",
     "ExportEC2InstanceRecommendationsResponseTypeDef",
+    "ExportLambdaFunctionRecommendationsResponseTypeDef",
     "FilterTypeDef",
     "GetAutoScalingGroupRecommendationsResponseTypeDef",
     "GetEBSVolumeRecommendationsResponseTypeDef",
@@ -117,7 +119,7 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
         "accountId": str,
         "autoScalingGroupArn": str,
         "autoScalingGroupName": str,
-        "finding": Finding,
+        "finding": FindingType,
         "utilizationMetrics": List["UtilizationMetricTypeDef"],
         "lookBackPeriodInDays": float,
         "currentConfiguration": "AutoScalingGroupConfigurationTypeDef",
@@ -148,8 +150,8 @@ EBSFilterTypeDef = TypedDict(
 EBSUtilizationMetricTypeDef = TypedDict(
     "EBSUtilizationMetricTypeDef",
     {
-        "name": EBSMetricName,
-        "statistic": MetricStatistic,
+        "name": EBSMetricNameType,
+        "statistic": MetricStatisticType,
         "value": float,
     },
     total=False,
@@ -172,6 +174,15 @@ ExportDestinationTypeDef = TypedDict(
     total=False,
 )
 
+ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
+    "ExportEBSVolumeRecommendationsResponseTypeDef",
+    {
+        "jobId": str,
+        "s3Destination": "S3DestinationTypeDef",
+    },
+    total=False,
+)
+
 ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     "ExportEC2InstanceRecommendationsResponseTypeDef",
     {
@@ -181,10 +192,19 @@ ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
+    "ExportLambdaFunctionRecommendationsResponseTypeDef",
+    {
+        "jobId": str,
+        "s3Destination": "S3DestinationTypeDef",
+    },
+    total=False,
+)
+
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
-        "name": FilterName,
+        "name": FilterNameType,
         "values": List[str],
     },
     total=False,
@@ -231,7 +251,7 @@ GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
 GetEnrollmentStatusResponseTypeDef = TypedDict(
     "GetEnrollmentStatusResponseTypeDef",
     {
-        "status": Status,
+        "status": StatusType,
         "statusReason": str,
         "memberAccountsEnrolled": bool,
     },
@@ -284,7 +304,7 @@ InstanceRecommendationTypeDef = TypedDict(
         "accountId": str,
         "instanceName": str,
         "currentInstanceType": str,
-        "finding": Finding,
+        "finding": FindingType,
         "utilizationMetrics": List["UtilizationMetricTypeDef"],
         "lookBackPeriodInDays": float,
         "recommendationOptions": List["InstanceRecommendationOptionTypeDef"],
@@ -297,7 +317,7 @@ InstanceRecommendationTypeDef = TypedDict(
 JobFilterTypeDef = TypedDict(
     "JobFilterTypeDef",
     {
-        "name": JobFilterName,
+        "name": JobFilterNameType,
         "values": List[str],
     },
     total=False,
@@ -307,7 +327,7 @@ LambdaFunctionMemoryProjectedMetricTypeDef = TypedDict(
     "LambdaFunctionMemoryProjectedMetricTypeDef",
     {
         "name": Literal["Duration"],
-        "statistic": LambdaFunctionMemoryMetricStatistic,
+        "statistic": LambdaFunctionMemoryMetricStatisticType,
         "value": float,
     },
     total=False,
@@ -326,7 +346,7 @@ LambdaFunctionMemoryRecommendationOptionTypeDef = TypedDict(
 LambdaFunctionRecommendationFilterTypeDef = TypedDict(
     "LambdaFunctionRecommendationFilterTypeDef",
     {
-        "name": LambdaFunctionRecommendationFilterName,
+        "name": LambdaFunctionRecommendationFilterNameType,
         "values": List[str],
     },
     total=False,
@@ -343,8 +363,8 @@ LambdaFunctionRecommendationTypeDef = TypedDict(
         "utilizationMetrics": List["LambdaFunctionUtilizationMetricTypeDef"],
         "lookbackPeriodInDays": float,
         "lastRefreshTimestamp": datetime,
-        "finding": LambdaFunctionRecommendationFinding,
-        "findingReasonCodes": List[LambdaFunctionRecommendationFindingReasonCode],
+        "finding": LambdaFunctionRecommendationFindingType,
+        "findingReasonCodes": List[LambdaFunctionRecommendationFindingReasonCodeType],
         "memorySizeRecommendationOptions": List["LambdaFunctionMemoryRecommendationOptionTypeDef"],
     },
     total=False,
@@ -353,8 +373,8 @@ LambdaFunctionRecommendationTypeDef = TypedDict(
 LambdaFunctionUtilizationMetricTypeDef = TypedDict(
     "LambdaFunctionUtilizationMetricTypeDef",
     {
-        "name": LambdaFunctionMetricName,
-        "statistic": LambdaFunctionMetricStatistic,
+        "name": LambdaFunctionMetricNameType,
+        "statistic": LambdaFunctionMetricStatisticType,
         "value": float,
     },
     total=False,
@@ -363,7 +383,7 @@ LambdaFunctionUtilizationMetricTypeDef = TypedDict(
 ProjectedMetricTypeDef = TypedDict(
     "ProjectedMetricTypeDef",
     {
-        "name": MetricName,
+        "name": MetricNameType,
         "timestamps": List[datetime],
         "values": List[float],
     },
@@ -373,7 +393,7 @@ ProjectedMetricTypeDef = TypedDict(
 ReasonCodeSummaryTypeDef = TypedDict(
     "ReasonCodeSummaryTypeDef",
     {
-        "name": FindingReasonCode,
+        "name": FindingReasonCodeType,
         "value": float,
     },
     total=False,
@@ -384,8 +404,8 @@ RecommendationExportJobTypeDef = TypedDict(
     {
         "jobId": str,
         "destination": "ExportDestinationTypeDef",
-        "resourceType": ResourceType,
-        "status": JobStatus,
+        "resourceType": ResourceTypeType,
+        "status": JobStatusType,
         "creationTimestamp": datetime,
         "lastUpdatedTimestamp": datetime,
         "failureReason": str,
@@ -397,7 +417,7 @@ RecommendationSourceTypeDef = TypedDict(
     "RecommendationSourceTypeDef",
     {
         "recommendationSourceArn": str,
-        "recommendationSourceType": RecommendationSourceType,
+        "recommendationSourceType": RecommendationSourceTypeType,
     },
     total=False,
 )
@@ -406,7 +426,7 @@ RecommendationSummaryTypeDef = TypedDict(
     "RecommendationSummaryTypeDef",
     {
         "summaries": List["SummaryTypeDef"],
-        "recommendationResourceType": RecommendationSourceType,
+        "recommendationResourceType": RecommendationSourceTypeType,
         "accountId": str,
     },
     total=False,
@@ -444,7 +464,7 @@ S3DestinationTypeDef = TypedDict(
 SummaryTypeDef = TypedDict(
     "SummaryTypeDef",
     {
-        "name": Finding,
+        "name": FindingType,
         "value": float,
         "reasonCodeSummaries": List["ReasonCodeSummaryTypeDef"],
     },
@@ -454,7 +474,7 @@ SummaryTypeDef = TypedDict(
 UpdateEnrollmentStatusResponseTypeDef = TypedDict(
     "UpdateEnrollmentStatusResponseTypeDef",
     {
-        "status": Status,
+        "status": StatusType,
         "statusReason": str,
     },
     total=False,
@@ -463,8 +483,8 @@ UpdateEnrollmentStatusResponseTypeDef = TypedDict(
 UtilizationMetricTypeDef = TypedDict(
     "UtilizationMetricTypeDef",
     {
-        "name": MetricName,
-        "statistic": MetricStatistic,
+        "name": MetricNameType,
+        "statistic": MetricStatisticType,
         "value": float,
     },
     total=False,
@@ -499,7 +519,7 @@ VolumeRecommendationTypeDef = TypedDict(
         "volumeArn": str,
         "accountId": str,
         "currentConfiguration": "VolumeConfigurationTypeDef",
-        "finding": EBSFinding,
+        "finding": EBSFindingType,
         "utilizationMetrics": List["EBSUtilizationMetricTypeDef"],
         "lookBackPeriodInDays": float,
         "volumeRecommendationOptions": List["VolumeRecommendationOptionTypeDef"],
